==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/dict_cc.md <==
## Dict.cc (SQLite3)

### General Information

| Attribute       | Value                                                                                            |
| --------------- | ------------------------------------------------------------------------------------------------ |
| Name            | Dictcc                                                                                           |
| snake_case_name | dict_cc                                                                                          |
| Description     | Dict.cc (SQLite3)                                                                                |
| Extensions      |                                                                                                  |
| Read support    | Yes                                                                                              |
| Write support   | No                                                                                               |
| Single-file     | No                                                                                               |
| Kind            | 🔢 binary                                                                                         |
| Sort-on-write   | default_no                                                                                       |
| Sort key        | (`headword_lower`)                                                                               |
| Wiki            | [Dict.cc](https://en.wikipedia.org/wiki/Dict.cc)                                                 |
| Website         | [dict.cc dictionary - Google Play](https://play.google.com/store/apps/details?id=cc.dict.dictcc) |



### Dictionary Applications/Tools

| Name & Website                                                                     | License     | Platforms |
| ---------------------------------------------------------------------------------- | ----------- | --------- |
| [dict.cc dictionary](https://play.google.com/store/apps/details?id=cc.dict.dictcc) | Proprietary | Android   |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/dict_cc.md <==
## Dict.cc (SQLite3)

### General Information

| Attribute       | Value                                                                                            |
| --------------- | ------------------------------------------------------------------------------------------------ |
| Name            | Dictcc                                                                                           |
| snake_case_name | dict_cc                                                                                          |
| Description     | Dict.cc (SQLite3)                                                                                |
| Extensions      |                                                                                                  |
| Read support    | Yes                                                                                              |
| Write support   | No                                                                                               |
| Single-file     | Yes                                                                                              |
| Kind            | 🔢 binary                                                                                         |
| Wiki            | [Dict.cc](https://en.wikipedia.org/wiki/Dict.cc)                                                 |
| Website         | [dict.cc dictionary - Google Play](https://play.google.com/store/apps/details?id=cc.dict.dictcc) |

### Dictionary Applications/Tools

| Name & Website                                                                     | Source code | License     | Platforms | Language |
| ---------------------------------------------------------------------------------- | ----------- | ----------- | --------- | -------- |
| [dict.cc dictionary](https://play.google.com/store/apps/details?id=cc.dict.dictcc) | ―           | Proprietary | Android   |          |
